@@ -3,4 +3,5 @@ import enum
 
 class TargetMode(enum.Enum):
     """Target mode enum for command discovery."""
-    CLASS = 'class'
+
+    CLASS = "class"
