@@ -3,7 +3,4 @@
 from .help_formatter import HierarchicalHelpFormatter
 from .help_formatting_engine import HelpFormattingEngine
 
-__all__ = [
-    'HierarchicalHelpFormatter',
-    'HelpFormattingEngine'
-]
+__all__ = ["HierarchicalHelpFormatter", "HelpFormattingEngine"]
