@@ -12,17 +12,17 @@ from .theme import (
 from .theme_style import CommandStyleSection, ThemeStyle
 
 __all__ = [
-  'AdjustStrategy',
-  'Back',
-  'ColorFormatter',
-  'CommandStyleSection',
-  'Fore',
-  'ForeUniversal',
-  'RGB',
-  'Style',
-  'Theme',
-  'ThemeStyle',
-  'create_default_theme',
-  'create_default_theme_colorful',
-  'create_no_color_theme',
+    "AdjustStrategy",
+    "Back",
+    "ColorFormatter",
+    "CommandStyleSection",
+    "Fore",
+    "ForeUniversal",
+    "RGB",
+    "Style",
+    "Theme",
+    "ThemeStyle",
+    "create_default_theme",
+    "create_default_theme_colorful",
+    "create_no_color_theme",
 ]
