@@ -3,17 +3,17 @@
 from .ansi_string import AnsiString
 from .data_struct_util import DataStructUtil
 from .math_util import MathUtil
-from .text_util import TextUtil
-from .spinner import ExecutionSpinner, CommandContext
 from .output_capture import OutputCapture, OutputFormatter
+from .spinner import CommandContext, ExecutionSpinner
+from .text_util import TextUtil
 
 __all__ = [
-    'AnsiString',
-    'DataStructUtil',
-    'MathUtil',
-    'TextUtil',
-    'ExecutionSpinner',
-    'CommandContext',
-    'OutputCapture',
-    'OutputFormatter'
+    "AnsiString",
+    "DataStructUtil",
+    "MathUtil",
+    "TextUtil",
+    "ExecutionSpinner",
+    "CommandContext",
+    "OutputCapture",
+    "OutputFormatter",
 ]
